@@ -10,10 +10,15 @@ from bleak_retry_connector import BLEDevice, establish_connection
 
 from . import util
 from .const import (
+    FIRMWARE_REVISION_CHARACTERISTIC,
+    MANUFACTURER_NAME_CHARACTERISTIC,
+    MODEL_NUMBER_CHARACTERISTIC,
+    SERIAL_NUMBER_CHARACTERISTIC,
     VALUE_TO_DOOR_STATUS,
     VALUE_TO_LOCK_STATUS,
     Commands,
     DoorStatus,
+    LockInfo,
     LockState,
     LockStatus,
 )
@@ -39,6 +44,13 @@ class Lock:
     def set_name(self, name: str) -> None:
         self.name = name
 
+    async def __aenter__(self) -> Lock:
+        await self.connect()
+        return self
+
+    async def __aexit__(self, exc_type: Any, exc_val: Any, exc_tb: Any) -> None:
+        await self.disconnect()
+
     def disconnected(self, *args: Any, **kwargs: Any) -> None:
         _LOGGER.debug("%s: Disconnected from lock callback", self.name)
         assert self._disconnected_event is not None  # nosec
@@ -56,6 +68,7 @@ class Lock:
             _LOGGER.error("%s: Failed to connect to the lock: %s", self.name, err)
             raise err
         _LOGGER.debug("%s: Connected", self.name)
+
         self.session = Session(self.client, self.name, self._lock)
         self.secure_session = SecureSession(
             self.client, self.name, self._lock, self.key_index
@@ -91,6 +104,20 @@ class Lock:
                 "Unexpected response to SEC_INITIALIZATION_COMMAND: " + response.hex()
             )
 
+    async def lock_info(self) -> LockInfo:
+        """Probe the lock for information."""
+        _LOGGER.debug("%s: Probing the lock", self.name)
+        assert self.client is not None  # nosec
+        lock_info = []
+        for char in (
+            MANUFACTURER_NAME_CHARACTERISTIC,
+            MODEL_NUMBER_CHARACTERISTIC,
+            SERIAL_NUMBER_CHARACTERISTIC,
+            FIRMWARE_REVISION_CHARACTERISTIC,
+        ):
+            lock_info.append((await self.client.read_gatt_char(char)).decode())
+        return LockInfo(*lock_info)
+
     async def force_lock(self) -> None:
         if not self.is_connected or not self.session:
             raise RuntimeError("Not connected")
